# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{ config, ... }:

{
  services.nginx.virtualHosts.${config.services.pretix.nginx.domain} = {
    enableACME = true;
    forceSSL = true;
  };

  services.pretix = {
    enable = true;

    plugins = with config.services.pretix.package.plugins; [
      pages
      passbook
    ];

    nginx = {
      enable = true;
      domain = "pretix.dgnum.eu";
    };

    environmentFile = config.age.secrets."pretix-environment_file".path;

    settings = {
      pretix = {
        instance_name = "pretix.dgnum.eu";
        url = "https://${config.services.pretix.nginx.domain}";
      };

      mail = {
        admins = "admins+pretix@dgnum.eu";

        from = "pretix@infra.dgnum.eu";
        host = "kurisu.lahfa.xyz";
        port = 465;
        ssl = "on";
        user = "web-services@infra.dgnum.eu";
      };

      locale = {
        default = "fr";
        timezone = "Europe/Paris";
      };
    };
  };

  dgn-backups = {
    postgresDatabases = [ "pretix" ];
    jobs.pretix.settings.paths = [ "/var/lib/pretix" ];
  };
}
