<!--
SPDX-FileCopyrightText: 2025 Tom Hubrecht <tom.hubrecht@dgnum.eu>

SPDX-License-Identifier: EUPL-1.2
-->

# ISO Installation

Once the iso is booted, there are several steps to take:

## Partition the disk

## Mount the partions

```bash
mount $rootDevice /mnt
mkdir /mnt/boot
mount $bootDevice /mnt/boot

swapon $swapDevice

nixos-generate-config --root /mnt
```

## Setup the base configuration

```bash
export NIX="/mnt/etc/nixos/"

mv $NIX/configuration.nix $NIX/base-configuration.nix
```

Edit a new file `configuration.nix` with the following contents:

```nix
{ pkgs, ... }:

{
  imports = [ ./base-configuration.nix ];

  boot = {
    tmp.cleanOnBoot = true;
  };

  console.keyMap = "fr";

  time.timeZone = "Europe/Paris";

  environment.systemPackages = with pkgs; [
    neovim
    wget
    kitty.terminfo
  ];

  # Activate SSH and set the keys
  services.openssh = {
    enable = true;

    settings.PasswordAuthentication = false;
  };

  users.users.root.openssh.authorizedKeys.keyFiles = [ ./rootKeys ];
}
```

### ZFS setup

If ZFS is to be installed (e.g. for large servers), add to the configuration:

```nix
  boot = {
    supportedFilesystems = [ "zfs" ];
    zfs.forceImportRoot = false;
    zfs.extraPools = [
      ...
    ];
  };

  networking.hostId = ...;
```

Where the list of pools to include is obtained with:

```bash
zpool list -Ho name | sed 's/^/"/;s/$/"/'
```

and the host id with:

```bash
head -c4 /dev/urandom | od -A none -t x4 | sed 's/ //'
```

## Setup the network configuration

Add the network configuration:

```nix
  networking = {
    hostName = "${name}";
    domain = "${site}.infra.dgnum.eu";

    useNetworkd = true;
  };

  systemd.network.networks = {
    "10-${interface}" = {
      name = ${interface};
      address = [ "${address}/${prefix}" ];
      routes = [ { Gateway = "..." ; GatewayOnLink = true; } ];
      dns = [ ... ];
    };
  };
```

If the default DNS are accessible, set them to:

```nix
[
  "1.1.1.1#cloudflare-dns.com"
  "8.8.8.8#dns.google"
  "1.0.0.1#cloudflare-dns.com"
  "8.8.4.4#dns.google"
]
```

Otherwise (in Jourdan especially), set them to the local DNS.

## Copy the ssh keys

```bash
cp /etc/ssh/authorized_keys.d/root $NIX/rootKeys
```

## Perform the installation

```bash
nixos-install
```
