# SPDX-FileCopyrightText: 2025 Lubin Bailly <lubin@dgnum.eu>
# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{
  pkgs,
  modulesPath,
  lib,
  ...
}:
let
  inherit (lib) mkForce;
in
{
  imports = [
    (modulesPath + "/installer/cd-dvd/installation-cd-minimal.nix")
  ];
  isoImage.squashfsCompression = ''zstd -Xcompression-level 1'';

  age-secrets.sources = mkForce [ ];
  dgn-records.enable = false;
  dgn-monitoring.enable = false;
  dgn-notify.enable = false;

  boot = {
    blacklistedKernelModules = [ "snd_pcsp" ];
    tmp.cleanOnBoot = true;

    loader = {
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };

    supportedFilesystems = {
      exfat = true;
      zfs = true;
    };

    swraid.enable = mkForce false;
  };

  networking = {
    networkmanager.enable = true;
    wireless.enable = false;
  };
  console.keyMap = "fr";

  environment.systemPackages = with pkgs; [
    perl
    git
  ];
  programs.zsh.enable = true;
  services = {
    openssh.enable = true;
    qemuGuest.enable = true;
    getty.autologinUser = mkForce "root";
  };
}
