# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2
{ config, ... }:
let
  url = "https://git.dgnum.eu";

  mkRunner =
    {
      labels,
      name,
      tokenFile,
    }:
    {
      enable = true;

      inherit
        name
        labels
        tokenFile
        url
        ;

      settings.container = {
        network = "host";
        options = "--cpus=4";
      };
    };
in

{
  services.gitea-actions-runner.instances = builtins.mapAttrs (_: mkRunner) {
    runner01 = {
      tokenFile = config.age.secrets."forgejo_runners-public-token_file".path;
      name = "storage01 [debian]";

      labels = [ "debian-latest:docker://node:20-bookworm" ];
    };

    runner02 = {
      tokenFile = config.age.secrets."forgejo_runners-public-token_file".path;
      name = "storage01 [debian]";

      labels = [ "debian-latest:docker://node:20-bookworm" ];
    };
  };

  virtualisation = {
    podman = {
      enable = true;

      defaultNetwork.settings = {
        dns_enable = true;
        ipv6_enabled = true;
      };
    };

    containers.storage.settings = {
      storage = {
        driver = "overlay";
        graphroot = "/data/slow/containers/storage";
        runroot = "/run/containers/storage";
      };
    };
  };
}
