# SPDX-FileCopyrightText: 2024 Maurice Debray <maurice.debray@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{ config, sources, ... }:
let
  dataDir = "/data/slow/tvix-store";
in
{

  imports = [

    "${sources.snix-cache}/nix/module.nix"
  ];
  nixpkgs.overlays = [

    (import "${sources.snix-cache}/nix/overlay.nix")
  ];
  age-secrets.autoMatch = [
    "snix-store"
    "nginx"
  ];

  services = {
    nginx.virtualHosts."snix-store.dgnum.eu" = {
      enableACME = true;
      forceSSL = true;
      serverAliases = [ "tvix-store.dgnum.eu" ];
    };
    snix-cache = {
      enable = true;
      storeComposition = {
        blobservices.default = {
          type = "objectstore";
          object_store_url = "file://${dataDir}/blob.objectstore";
          object_store_options = { };
        };
        directoryservices = {
          redb = {
            type = "redb";
            is_temporary = false;
            path = "${dataDir}/directory.redb";
          };
        };
        pathinfoservices = {
          infra = {
            type = "redb";
            is_temporary = false;
            path = "${dataDir}/pathinfo.redb";
          };
        };
      };
      host = "snix-store.dgnum.eu";
      caches = {
        infra = {
          maxBodySize = "50G";

          directoryService = "redb";
          blobService = "default";
          uploadPasswordFile = config.age.secrets."nginx-snix_cache_infra".path;
          signing = {
            passwordFile = config.age.secrets."nginx-snix_cache_infra.signing".path;
            keyFile = config.age.secrets."snix-cache-infra_signing_key".path;
            publicKey = "infra.snix-store.dgnum.eu-1:8CAY64o3rKjyw2uA5mzr/aTzstnc+Uj4g8OC6ClG1m8=";
          };
        };
      };
    };
  };

  systemd.services.snix-cache.serviceConfig.ReadWritePaths = [ dataDir ];
}
