# SPDX-FileCopyrightText: 2024 Tom Hubrecht <tom.hubrecht@dgnum.eu>
#
# SPDX-License-Identifier: EUPL-1.2

{ config, ... }:

{
  services.django-apps.sites.annuaire = {
    source = "https://git.dgnum.eu/DGNum/annuaire-eleves";
    branch = "main";
    domain = "annuaire-ens.webapps.dgnum.eu";

    nginx = {
      enableACME = true;
      forceSSL = true;
    };

    webHookSecret = config.age.secrets."webhook-annuaire_token".path;

    overlays.nix-pkgs = [
      "authens"
      "loadcredential"

      # Dependencies
      "python-cas"
    ];

    dependencies = ps: [
      ps.authens
      ps.django
      ps.loadcredential
      ps.pillow
      ps.python-dateutil
    ];

    credentials = {
      SECRET_KEY = config.age.secrets."dj_annuaire-secret_key_file".path;
    };

    environment = {
      ANNUAIRE_LDAP = {
        SPI = {
          PROTOCOL = "ldaps";
          URL = "ldap.spi.ens.fr";
          PORT = 636;
        };
        CRI = {
          PROTOCOL = "ldaps";
          URL = "annuaire.ens.fr";
          PORT = 636;
        };
      };
    };
  };
}
